@@ -29,19 +29,22 @@ package Sidef::Module::OO {
                    : ()
         );
 
+        my $multi_values = wantarray;
+
         my @results = do {
             local *UNIVERSAL::AUTOLOAD;
-            $self->{module}->$method(@args);
+            $multi_values ? ($self->{module}->$method(@args)) : (scalar $self->{module}->$method(@args));
         };
 
-        my $multi_values = wantarray // return;
+        $multi_values // return;
+
+        @results = map { Sidef::Perl::Perl->to_sidef($_) } @results;
 
         if (@results > 1) {
-            @results = map { Sidef::Perl::Perl->to_sidef($_) } @results;
             return ($multi_values ? @results : Sidef::Types::Array::Array->new(\@results));
         }
 
-        Sidef::Perl::Perl->to_sidef($results[0]);
+        $results[0];
     }
 }
 
