@@ -5,7 +5,7 @@ package Sidef::Types::Glob::FileHandle {
 
     use parent qw(
       Sidef::Object::Object
-      );
+    );
 
     use Sidef::Types::Bool::Bool;
 
@@ -29,6 +29,8 @@ package Sidef::Types::Glob::FileHandle {
         $_[0]{parent};
     }
 
+    *file = \&parent;
+
     sub is_on_tty {
         (-t $_[0]{fh}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE);
     }
@@ -50,17 +52,22 @@ package Sidef::Types::Glob::FileHandle {
     sub autoflush {
         my ($self, $bool) = @_;
         select((select($self->{fh}), $| = $bool ? 1 : 0)[0]);
-        $bool;
+        $self;
     }
 
     sub binmode {
         my ($self, $encoding) = @_;
         CORE::binmode($self->{fh}, "$encoding");
+        $self;
     }
 
     sub syswrite {
-        my ($self, @args) = @_;
-        (CORE::syswrite $self->{fh}, @args) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE);
+        my ($self, $scalar, $length, $offset) = @_;
+        (
+           defined($offset) ? (CORE::syswrite $self->{fh}, $scalar, $length, $offset)
+         : defined($length) ? (CORE::syswrite $self->{fh}, $scalar, $length)
+         :                    (CORE::syswrite $self->{fh}, $scalar)
+        ) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub print {
@@ -274,27 +281,26 @@ package Sidef::Types::Glob::FileHandle {
 
     sub tell {
         my ($self) = @_;
-        Sidef::Types::Number::Number->new(tell($self->{fh}));
+        Sidef::Types::Number::Number->new(CORE::tell($self->{fh}));
     }
 
     sub seek {
         my ($self, $pos, $whence) = @_;
-        seek($self->{fh}, $pos, $whence,)
+        CORE::seek($self->{fh}, $pos, $whence)
           ? (Sidef::Types::Bool::Bool::TRUE)
           : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub sysseek {
         my ($self, $pos, $whence) = @_;
-
-        sysseek($self->{fh}, $pos, $whence,)
+        CORE::sysseek($self->{fh}, $pos, $whence)
           ? (Sidef::Types::Bool::Bool::TRUE)
           : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub fileno {
         my ($self) = @_;
-        Sidef::Types::Number::Number->new(fileno($self->{fh}));
+        Sidef::Types::Number::Number->new(CORE::fileno($self->{fh}));
     }
 
     sub lock {
