@@ -40,6 +40,11 @@ package Sidef::Types::Number::Gauss {
         __PACKAGE__->new($x->{a}->eval($v), $x->{b}->eval($v));
     }
 
+    sub lift {
+        my ($x) = @_;
+        __PACKAGE__->new($x->{a}->lift, $x->{b}->lift);
+    }
+
     sub i {
         my ($x) = @_;
 
@@ -106,6 +111,8 @@ package Sidef::Types::Number::Gauss {
         Sidef::Types::String::String->new(join(' + ', $x->{a}->stringify, join('', '(', $x->{b}->stringify, ')*1i')));
     }
 
+    *pretty = \&stringify;
+
     sub abs {
         my ($x) = @_;
         $x->{a}->sqr->add($x->{b}->sqr)->sqrt;
